==> secioss-idsuite-cloud-idp-3.0.2.zip: secioss-idsuite-cloud-idp-3.0.2/opt/secioss/share/simplesamlphp/metadata/saml20-sp-remote.php <==
<?php
/* 
 * SAML 2.0 Meta data for simpleSAMLphp
 *
 * The SAML 2.0 SP Remote config is used by the SAML 2.0 IdP to identify trusted SAML 2.0 SPs.
 *
 * Required parameters:
 *   - AssertionConsumerService
 *   - SingleLogoutService
 *
 * Optional parameters:
 *
 *   - simplesaml.attributes (Will you send an attributestatement [true/false])
 *   - NameIDFormat
 *   - ForceAuthn (default: "false")
 *   - simplesaml.nameidattribute (only needed when you are using NameID format email.
 *
 *   - 'base64attributes'	=>	false,
 *   - 'simplesaml.attributes'	=>	true,
 *   - 'attributemap'		=>	'test',
 *   - 'attributes'			=>	array('mail'),
 *   - 'userid.attribute'
 *
 * Request signing
 *    When request.signing is true the certificate of the sp 
 *    will be used to verify all messages received with the HTTPRedirect binding.
 *    The certificate from the SP must be installed in the cert directory 
 *    before verification can be done.  
 *
 *   'request.signing' => false,
 *   'certificate' => "saml2sp.example.org.crt"
 *
 */

$metadata = array(
        'https://sp.example.com' => array(
                'AssertionConsumerService' => 'https://sp.example.com/saml/saml2/sp/AssertionConsumerService.php',
                'SingleLogoutService' => 'https://sp.example.com/saml/saml2/sp/SingleLogoutService.php',
                'NameIDFormat' => 'urn:oasis:names:tc:SAML:2.0:nameid-format:persistent',
                'simplesaml.nameidattribute' => 'seciosssystemid',
                'simplesaml.attributes' => true,
                'attributes' => array('seciosssystemid', 'seciossallowedservice'),
                'authproc' => array(
                    50 => array(
                        'class' => 'core:AttributeMap',
                        'uid' => 'seciosssystemid',
                        'sAMAccountName' => 'seciosssystemid'
                    ),
                    60 => array(
                        'class' => 'core:AttributeAdd', 
                        'seciossallowedservice' => array('')
                    ),
                    100 => array(
                        'class' => 'core:AttributeLimit'
                    ),
                )
        ),
);
?>

==> secioss-idsuite-cloud-idp-3.1.1.zip: secioss-idsuite-cloud-idp-3.1.1/opt/secioss/share/simplesamlphp/metadata/saml20-sp-remote.php <==
<?php
/* 
 * SAML 2.0 Meta data for simpleSAMLphp
 *
 * The SAML 2.0 SP Remote config is used by the SAML 2.0 IdP to identify trusted SAML 2.0 SPs.
 *
 * Required parameters:
 *   - AssertionConsumerService
 *   - SingleLogoutService
 *
 * Optional parameters:
 *
 *   - simplesaml.attributes (Will you send an attributestatement [true/false])
 *   - NameIDFormat
 *   - ForceAuthn (default: "false")
 *   - simplesaml.nameidattribute (only needed when you are using NameID format email.
 *
 *   - 'base64attributes'	=>	false,
 *   - 'simplesaml.attributes'	=>	true,
 *   - 'attributemap'		=>	'test',
 *   - 'attributes'			=>	array('mail'),
 *   - 'userid.attribute'
 *
 * Request signing
 *    When request.signing is true the certificate of the sp 
 *    will be used to verify all messages received with the HTTPRedirect binding.
 *    The certificate from the SP must be installed in the cert directory 
 *    before verification can be done.  
 *
 *   'request.signing' => false,
 *   'certificate' => "saml2sp.example.org.crt"
 *
 */

$metadata = array(
        'https://slink.secioss.com' => array(
                'AssertionConsumerService' => 'https://slink.secioss.com/saml/saml2/sp/AssertionConsumerService.php',
                'SingleLogoutService' => 'https://slink.secioss.com/saml/saml2/sp/SingleLogoutService.php',
                'NameIDFormat' => 'urn:oasis:names:tc:SAML:2.0:nameid-format:persistent',
                'simplesaml.nameidattribute' => 'seciosssystemid',
                'simplesaml.attributes' => true,
                'attributes' => array('seciosssystemid', 'seciossallowedservice'),
                'authproc' => array(
                    50 => array(
                        'class' => 'core:AttributeMap',
                        'uid' => 'seciosssystemid',
                        'sAMAccountName' => 'seciosssystemid'
                    ),
                    60 => array(
                        'class' => 'core:AttributeAdd', 
                        'seciossallowedservice' => array('')
                    ),
                    100 => array(
                        'class' => 'core:AttributeLimit'
                    ),
                )
        ),
);
?>
